@@ -28,7 +28,7 @@ Template::Plugin::PodSimple - simple Pod::Simple plugin for TT
     [% PodSimple.parse('Text', somepod) %]
     [% PodSimple.parse('xml', somepod) %]
     [% mySimpleTree = PodSimple.parse('tree', somepod ) %]
-    [% PodSimple.parse('html', somepod, 'prefix') %]
+    [% PodSimple.parse('html', somepod, 'pod_link_prefix','man_link_prefix') %]
 
 Text translates to L<Pod::Simple::Text|Pod::Simple::Text>.
 
@@ -39,10 +39,17 @@ and the tree B<root> is what's returned.
 This is what you want to use if you want to create your own formatter.
 
 htMl translates to L<Pod::Simple::HTML|Pod::Simple::HTML>.
-When dealing with htMl, the 3rd argument (prefix)
+When dealing with htMl, the 3rd and 4th arguments are
 is used to prefix all non-local LE<lt>E<gt>inks,
-by temporarily overriding C<< *Pod::Simple::HTML::resolve_pod_page_link >>.
-Prefix is "B<?>" by default.
+by temporarily overriding
+C<< *Pod::Simple::HTML::do_pod_link >>.
+and
+C<< *Pod::Simple::HTML::do_man_link >>.
+pod_link_prefix is "?" by default.
+man_link_prefix is C<< http://man.linuxquestions.org/index.php?type=2&query= >>
+by default.
+The prefix always gets html escaped by Pod::Simple.
+An example man link is C<< L<crontab(5)> >>.
 
 
 
@@ -73,7 +80,7 @@ use Pod::Simple;
 use Carp 'croak';
 use base qw[ Template::Plugin ];
 use vars '$VERSION';
-$VERSION = sprintf "%d.%03d", q$Revision: 1.5 $ =~ /(\d+).(\d+)/g;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.7 $ =~ /(\d+).(\d+)/g;
 
 
 my %map = (
@@ -83,10 +90,61 @@ my %map = (
     xml  => 'XMLOutStream',
 );
 
+my $pod_link_prefix = '';
+my $man_link_prefix = '';
+sub _do_man_link {
+    my($self, $link) = @_;
+    my $to = $link->attr('to');
+    $to =~ s/\(\d+\)$//;
+    return $man_link_prefix.$self->unicode_escape_url($to);
+}
+sub _do_pod_link {
+  my($self, $link) = @_;
+  my $to = $link->attr('to');
+  my $section = $link->attr('section');
+  return undef unless(  # should never happen
+    (defined $to and length $to) or
+    (defined $section and length $section)
+  );
+
+#  if(defined $to and length $to) {
+#    $to = $self->resolve_pod_page_link($to, $section);
+#    return undef unless defined $to and length $to;
+     # resolve_pod_page_link returning undef is how it
+     #  can signal that it gives up on making a link
+     # (I pass it the section value, but I don't see a
+     #  particular reason it'd use it.)
+#  }
+  
+  if(defined $section and length($section .= '')) {
+    $section =~ tr/ /_/;
+    $section =~ tr/\x00-\x1F\x80-\x9F//d if 'A' eq chr(65);
+    $section = $self->unicode_escape_url($section);
+     # Turn char 1234 into "(1234)"
+    $section = '_' unless length $section;
+  }
+  
+  foreach my $it ($to, $section) {
+    $it =~ s/([^\._abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/sprintf('%%%02X',ord($1))/eg
+     if defined $it;
+      # Yes, stipulate the list without a range, so that this can work right on
+      #  all charsets that this module happens to run under.
+      # Altho, hmm, what about that ord?  Presumably that won't work right
+      #  under non-ASCII charsets.  Something should be done about that.
+  }
+  
+  my $out = $to if defined $to and length $to;
+  $out .= "#" . $section if defined $section and length $section;
+  return undef unless length $out;
+  return $pod_link_prefix.$out;  
+}
+
 sub parse {
     my $self = shift;
     my $class = lc shift;
-    my $prefix = $_[1] || '?';
+    $pod_link_prefix = $_[1] || '?';
+    $man_link_prefix = $_[2] || 'http://man.linuxquestions.org/index.php?type=2&query=';
+
     my $somestring="";
     my $new;
 
@@ -103,10 +161,10 @@ sub parse {
 
     $new->output_string( \$somestring );
 
-    local *Pod::Simple::HTML::resolve_pod_page_link = sub {
-        my($self, $to) = @_;
-        return "$prefix$to";
-    } if $class =~ /html/i;
+    local *Pod::Simple::HTML::do_pod_link = \&_do_pod_link
+        and
+        local *Pod::Simple::HTML::do_man_link = \&_do_man_link
+            if $class =~ /html/i;
 
     if( $_[0] =~ /\n/ ){
         $new->parse_string_document( $_[0] );
